/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.forms');

/**
 * Do not call this contructor
 * @constructor
 * @class This class handles the tab that shows when selection is of the configured HTML node type in the edition form
 * @param {String} id The unique tab identifier
 * @param {Map<id, value>} configuration The configuration of the control instance. The key 'node-type' represents the name of the HTML node that will make the tab show when this kind of target is in the {@see org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED} message.
 * @param {String} The name of the plugin where the control was declared
 * @param {Ext.Panel} The panel of the tab
 */
org.ametys.forms.FormTab = function(id, configuration, pluginName, tabPanel) 
{
	org.ametys.forms.FormTab.superclass.constructor.call(this, id, configuration, pluginName, tabPanel);
};

Ext.extend(org.ametys.forms.FormTab, org.ametys.cms.ribbon.tab.EditorTab, {});

org.ametys.cms.ribbon.tab.EditorTab.prototype._getNode = function(base)
{
	var node = tinyMCE.activeEditor.dom.getParent(base, "label");

	if (node != null)
	{
		var id = node.htmlFor;
		if (id != null)
		{
			var field = tinyMCE.activeEditor.dom.get(id);
			if (field != null)
			{
				return field;
			}
		}
	}
	
	return base;
}
